@@ -144,7 +144,7 @@ def create_venue_uwsgi_file(VENUE_ROOT, VENUE_NAME):
     srcfile = os.path.join(os.path.dirname(backstage.__file__), 'conf/uwsgi.venue.ini.src')
     with open(srcfile, 'r') as f:
         srcdata = f.read()
-    outfile = os.path.join(VENUE_ROOT, 'uwsgi.ini')
+    outfile = os.path.join(VENUE_ROOT, 'backstage-%s-uwsgi.ini' % (VENUE_NAME))
     o = open(outfile, 'w')
     o.write(srcdata.format(VENUE_ROOT=VENUE_ROOT, VENUE_NAME=VENUE_NAME))
     o.close()
